0.9.9 API documentation: matrix_float4x3_precision.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

matrix_float4x3_precision.hpp
Go to the documentation of this file.
1
4 #pragma once
5 #include "../detail/type_mat4x3.hpp"
6
7 namespace glm
8 {
11
16 typedef mat<4, 3, float, lowp> lowp_mat4x3;
17
22 typedef mat<4, 3, float, mediump> mediump_mat4x3;
23
28 typedef mat<4, 3, float, highp> highp_mat4x3;
29
31 }//namespace glm
glm::highp_mat4x3
mat< 4, 3, float, highp > highp_mat4x3
4 columns of 3 components matrix of single-precision floating-point numbers using high precision arit...
Definition: matrix_float4x3_precision.hpp:28
glm::lowp_mat4x3
mat< 4, 3, float, lowp > lowp_mat4x3
4 columns of 3 components matrix of single-precision floating-point numbers using low precision arith...
Definition: matrix_float4x3_precision.hpp:16
glm::mediump_mat4x3
mat< 4, 3, float, mediump > mediump_mat4x3
4 columns of 3 components matrix of single-precision floating-point numbers using medium precision ar...
Definition: matrix_float4x3_precision.hpp:22
glm
Definition: common.hpp:20